@@ -14,5 +14,13 @@ class CommandNameAlreadyUsedError(RuntimeError):
         super().__init__("The command name: %s is already used" % name)
 
 
-class ConversionError(RuntimeError):
+class ValidationError(RuntimeError):
+    pass
+
+
+class ConversionError(ValidationError):
+    pass
+
+
+class MenuExitException(RuntimeError):
     pass
